%define anolis_release 2

Name: nghttp2
Version: 1.58.0
Release: %{anolis_release}%{?dist}
License: MIT
Summary: Experimental HTTP/2 client, server and proxy
URL: https://nghttp2.org/
Source0: https://github.com/tatsuhiro-t/nghttp2/releases/download/v%{version}/nghttp2-%{version}.tar.xz

Patch1000:     0001-CVE-2024-28182_1.patch
Patch1001:     0002-CVE-2024-28182_2.patch

BuildRequires: gcc-c++
BuildRequires: make
BuildRequires: systemd
BuildRequires: libev-devel
BuildRequires: python3-devel >= 3.8
BuildRequires: pkgconfig(cunit) >= 2.1
BuildRequires: pkgconfig(libbpf) >= 0.7.0
BuildRequires: pkgconfig(libcares) >= 1.7.5
BuildRequires: pkgconfig(libevent_openssl) >= 2.0.8
BuildRequires: pkgconfig(libsystemd) >= 209
BuildRequires: pkgconfig(libxml-2.0) >= 2.6.26
BuildRequires: pkgconfig(jansson) >= 2.5
BuildRequires: pkgconfig(jemalloc)
BuildRequires: pkgconfig(openssl) >= 1.0.1
BuildRequires: pkgconfig(zlib) >= 1.2.3

Requires: libnghttp2 = %{version}-%{release}
%{?systemd_requires}

%description
This package contains the HTTP/2 client, server and proxy programs.


%package -n libnghttp2
Summary: A library implementing the HTTP/2 protocol

%description -n libnghttp2
libnghttp2 is a library implementing the Hypertext Transfer Protocol
version 2 (HTTP/2) protocol in C.


%package -n libnghttp2-devel
Summary: Files needed for building applications with libnghttp2
Requires: libnghttp2 = %{version}-%{release}

%description -n libnghttp2-devel
The libnghttp2-devel package includes libraries and header files needed
for building applications with libnghttp2.

%package doc
Summary: Doc files for %{name}
Requires: %{name} = %{EVR}
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}

%prep
%autosetup -p1

# make fetch-ocsp-response use Python 3
sed -e '1 s|^#!/.*python|&3|' -i script/fetch-ocsp-response

%build
%configure \
    --disable-hpack-tools                   \
    --disable-static                        \
    --with-libxml2

%make_build


%install
%make_install
install -D -m0444 -p contrib/nghttpx.service \
    "$RPM_BUILD_ROOT%{_unitdir}/nghttpx.service"

# will be installed via %%doc
rm -f "$RPM_BUILD_ROOT%{_datadir}/doc/nghttp2/README.rst"

%generate_compatibility_deps

%post
%systemd_post nghttpx.service

%postun
%systemd_postun nghttpx.service

# aarch64 faild when check
%ifarch x86_64 loongarch64
%check
# test the just built library instead of the system one, without using rpath
export "LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir}:$LD_LIBRARY_PATH"
%make_build check
%endif

%files
%{_bindir}/h2load
%{_bindir}/nghttp
%{_bindir}/nghttpd
%{_bindir}/nghttpx
%ifarch x86_64 loongarch64
%{abidir}/h2load-option.list
%{abidir}/nghttp-option.list
%{abidir}/nghttpx-option.list
%endif
%{abidir}/nghttpd-option.list
%{_datadir}/nghttp2
%{_mandir}/man1/h2load.1*
%{_mandir}/man1/nghttp.1*
%{_mandir}/man1/nghttpd.1*
%{_mandir}/man1/nghttpx.1*
%{_unitdir}/nghttpx.service

%files -n libnghttp2
%dir %{abidir}
%{_libdir}/libnghttp2.so.*
%{abidir}/libnghttp2*.dump
%license COPYING

%files -n libnghttp2-devel
%{_includedir}/nghttp2
%{_libdir}/pkgconfig/libnghttp2.pc
%{_libdir}/libnghttp2.so

%files doc
%doc AUTHORS ChangeLog NEWS README README.rst

%changelog
* Mon Nov 11 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.58.0-2
- add patch to fix CVE-2024-28182

* Mon Mar 11 2024 <doupengda@loongson.cn> - 1.58.0-1
- New version 1.58.0

* Wed Oct 11 2023 Funda Wang <fundawang@yeah.net> - 1.57.0-1
- New version 1.57.0

* Wed Jul 12 2023 Funda Wang <fundawang@yeah.net> - 1.55.0-1
- New version 1.55.0

* Fri Feb 17 2023 Funda Wang <fundawang@yeah.net> - 1.52.0-1
- New version 1.52.0

* Wed Feb 08 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.51.0-1
- update to version 1.51.0

* Mon Oct 24 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.49.0-2
- optimise spec file

* Mon Sep 5 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.49.0-1
- update to 1.49.0

* Thu Mar 10 2022 DengXiewei <dengxiewei@linux.alibaba.com> - 1.46.0-1
- Init from upstream 1.46.0
